# README #

### Repository purpose ###

This repository includes analysis tools for analyzing galaxy formation simulations, focusing on the FIRE simulations.
It's currently under development, with no official release yet.

### Installation ###

Using pip to install is easiest:
```
pip install galaxy-dive
```

Otherwise, clone the repository and add it to your paths.

### Contribution guidelines ###

I don't expect anyone to contribute to the repository at this point in time.

### Who do I talk to? ###

Zach Hafen (zachary.h.hafen@gmail.com) is the repository owner. Contact him for questions.
This was developed while working in [Northwestern University's galaxy formation group](http://galaxies.northwestern.edu/).
